"""
Constants used throughout the spryx-core package.

This module defines constants that are used across the package,
such as sentinel instances.
"""

from spryx_core.sentinels import NotGiven

# Singleton instance of NotGiven sentinel
NOT_GIVEN = NotGiven
